teatime.plugins package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   teatime.plugins.eth1

Submodules
----------

teatime.plugins.base module
---------------------------

.. automodule:: teatime.plugins.base
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:


teatime.plugins.context module
------------------------------

.. automodule:: teatime.plugins.context
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:


Module contents
---------------

.. automodule:: teatime.plugins
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
